@@ -46,7 +46,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.57_03'; # TRIAL VERSION
+our $VERSION = '1.58_01'; # TRIAL VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -68,6 +68,7 @@ our $VERSION = '1.57_03'; # TRIAL VERSION
     CSE
     Cdnfundlibrary
     Comdirect
+    Consorsbank
     Currencies
     DWS
     Deka
@@ -94,6 +95,7 @@ our $VERSION = '1.57_03'; # TRIAL VERSION
     SEB
     SIX
     Sinvestor
+    Stooq
     TesouroDireto
     Tiaacref
     TMX
@@ -1688,6 +1690,7 @@ http://www.gnucash.org/
   Finance::Quote::CSE,
   Finance::Quote::Cdnfundlibrary,
   Finance::Quote::Comdirect,
+  Finance::Quote::Consorsbank,
   Finance::Quote::Currencies,
   Finance::Quote::DWS,
   Finance::Quote::Deka,
