@@ -5,13 +5,15 @@
 #
 
 package Finance::Quote::BSEIndia;
-require 5.010;
 
 use strict;
 use POSIX qw(strftime);
 use IO::Uncompress::Unzip qw(unzip $UnzipError);
 
-our $VERSION = '1.57_03'; # TRIAL VERSION
+use constant DEBUG => $ENV{DEBUG};
+use if DEBUG, 'Smart::Comments', '###';
+
+our $VERSION = '1.58_01'; # TRIAL VERSION
 
 use vars qw($BSE_URL);
 $BSE_URL = "https://www.bseindia.com";
@@ -125,7 +127,7 @@ sub bseindia {
 
     foreach my $symbol (@symbols) {
         unless (exists $info{$symbol, 'success'}) {
-        print "$symbol not found\n";
+        ### Not Found: $symbol
         $info{$symbol, 'success'} = 0;
         $info{$symbol, 'errormsg'} = 'Stock not found on BSE.';
     }
