@@ -4,10 +4,11 @@ use strict;
 
 use LWP::UserAgent;
 use HTTP::Request::Common;
+use HTTP::CookieJar::LWP ();
 use HTML::TreeBuilder;
 use Encode;
 
-our $VERSION = '1.57_03'; # TRIAL VERSION
+our $VERSION = '1.58_01'; # TRIAL VERSION
 
 use vars qw($BLOOMBERG_URL);
 
@@ -16,7 +17,7 @@ $BLOOMBERG_URL = 'https://www.bloomberg.com/quote/';
 sub methods { return (bloomberg => \&bloomberg); }
 
 {
-  my @labels = qw/method last currency symbol isodate/;
+  my @labels = qw/method name last currency symbol isodate/;
 
   sub labels { return (bloomberg => \@labels); }
 }
@@ -26,13 +27,14 @@ sub bloomberg {
   my @symbols = @_;
 
   return unless @symbols;
-  my ($ua, $reply, $url, %funds, $te, $table, $row, @value_currency, $name);
+  my ($ua, $cj, $reply, $url, %funds, $te, $table, $row, @value_currency, $name);
 
   foreach my $symbol (@symbols) {
     $name = $symbol;
     $url  = $BLOOMBERG_URL;
     $url  = $url . $name;
-    $ua   = LWP::UserAgent->new;
+    $cj   = HTTP::CookieJar::LWP->new;
+    $ua   = LWP::UserAgent->new(cookie_jar => $cj);
     my @ns_headers = (
         'User-Agent' => 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:67.0) Gecko/20100101 Firefox/67.0', 
         'Referer' => 'https://www.bloomberg.com/',
@@ -50,14 +52,22 @@ sub bloomberg {
 
     eval {
       my $tree  = HTML::TreeBuilder->new_from_content(decode_utf8 $reply->content);
-      my $price = $tree->look_down(_tag=>'span', 'class'=>qr/^priceText_/)->as_text();
-      my $curr  = $tree->look_down(_tag=>'span', 'class'=>qr/^currency_/)->as_text();
-      my $date  = $tree->look_down(_tag=>'div', sub {defined($_[0]->attr('class')) and $_[0]->attr('class') =~ /time__/})->as_text();
+      my $desc  = $tree->look_down(_tag=>'div', 'class'=>qr/SecurityName_extraLarge/)->as_text();
+      my $price = $tree->look_down(_tag=>'div', 'class'=>qr/^sized-price SizedPrice_extraLarge/)->as_text();
+      my $curr  = $tree->look_down(_tag=>'span', 'class'=>qr/^quotePageHeader_securityDetails/)->as_text();
+      my $date  = $tree->look_down(_tag=>'span', 'class'=>qr/^marketStatus_exchangeDelay/)->right();
 
+      $curr =~ s/.*[(](.*)[)].*/$1/;
       $price =~ s/,//g;
+      if ($curr eq "GBp") {
+        $curr = "GBP";
+        $price = $price / 100;
+      }
+      $date = $1 . "20" . $2 if $date =~ m|([0-9]{1,2}/[0-9]{1,2}/)([0-9]{2})$|;
       $date = $1 if $date =~ m|([0-9]{1,2}/[0-9]{1,2}/[0-9]{4})|;
 
       $funds{$name, 'method'}   = 'bloomberg';
+      $funds{$name, 'name'}     = $desc;
       $funds{$name, 'last'}     = $price;
       $funds{$name, 'currency'} = $curr;
       $funds{$name, 'symbol'}   = $name;
@@ -102,7 +112,7 @@ The security string must match the format expected by the site, such as
 
 =head1 LABELS RETURNED
 
-Labels returned by this module include: last, currency, symbol, isodate
+Labels returned by this module include: name, last, currency, symbol, isodate
 
 =head1 SEE ALSO
 
